@@ -1,7 +1,7 @@
 package WWW::DistroWatch::ReleaseInfo;
 
-our $DATE = '2015-10-06'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2018-01-22'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ sub list_distros {
             $html = <$fh>;
         }
     } else {
-        my $url = "http://distrowatch.com/";
+        my $url = "https://distrowatch.com/";
         my $tx = $ua->get($url);
         unless ($tx->success) {
             my $err = $tx->error;
@@ -71,10 +71,10 @@ our $distros = do {
     no warnings 'void';
     {};
  {
-   "0linux"         => "0Linux",
-   "2x"             => "2XOS",
+   "3cx"            => "3CX",
    "4mlinux"        => "4MLinux",
    "absolute"       => "Absolute",
+   "abuledu"        => "Abul\xC3\x83\xC2\x89du",
    "alpine"         => "Alpine",
    "alt"            => "ALT",
    "androidx86"     => "Android-x86",
@@ -83,194 +83,217 @@ our $distros = do {
    "apodio"         => "APODIO",
    "arch"           => "Arch",
    "archbang"       => "ArchBang",
-   "artistx"        => "ArtistX",
+   "archlabs"       => "ArchLabs",
+   "archman"        => "Archman",
+   "archstrike"     => "ArchStrike",
+   "artix"          => "Artix",
+   "arya"           => "Arya",
+   "asianux"        => "Asianux",
    "asterisknow"    => "AsteriskNOW",
+   "audiophile"     => "Audiophile",
    "austrumi"       => "AUSTRUMI",
    "avlinux"        => "AV Linux",
    "backbox"        => "BackBox",
-   "baltix"         => "Baltix",
-   "bardinux"       => "Bardinux",
+   "backslash"      => "BackSlash",
    "baruwa"         => "Baruwa",
-   "bella"          => "Bella",
+   "beefree"        => "BeeFree",
    "berry"          => "Berry",
    "bicom"          => "Bicom",
+   "biglinux"       => "BigLinux",
    "biolinux"       => "Bio-Linux",
+   "bitkey"         => "BitKey",
    "blackarch"      => "BlackArch",
    "blacklab"       => "Black Lab",
    "blackpanther"   => "blackPanther",
-   "blag"           => "BLAG",
    "blankon"        => "BlankOn",
+   "blueonyx"       => "BlueOnyx",
+   "bluestar"       => "Bluestar",
    "bodhi"          => "Bodhi",
    "boss"           => "BOSS",
-   "bridge"         => "Bridge",
+   "bsdrp"          => "BSDRP",
+   "bunsenlabs"     => "BunsenLabs",
    "cae"            => "CAELinux",
    "caine"          => "CAINE",
-   "caixamagica"    => "Caixa M\xE1gica",
    "calculate"      => "Calculate",
    "canaima"        => "Canaima",
-   "catix"          => "C\xE0tix",
    "centos"         => "CentOS",
-   "centrych"       => "Centrych",
    "chakra"         => "Chakra",
    "chaletos"       => "ChaletOS",
    "chapeau"        => "Chapeau",
-   "chitwanix"      => "Chitwanix",
-   "chromixium"     => "Chromixium",
+   "clear"          => "Clear",
    "clearos"        => "ClearOS",
    "clonezilla"     => "Clonezilla",
+   "clonos"         => "ClonOS",
+   "cloudready"     => "CloudReady",
    "connochaet"     => "Connochaet",
-   "coreos"         => "CoreOS",
+   "container"      => "Container",
    "crux"           => "CRUX",
+   "cucumber"       => "Cucumber",
+   "daphile"        => "Daphile",
    "debian"         => "Debian",
    "deepin"         => "deepin",
    "deft"           => "DEFT",
-   "devil"          => "Devil",
-   "doudou"         => "DoudouLinux",
+   "devuan"         => "Devuan",
+   "dietpi"         => "DietPi",
    "dragonflybsd"   => "DragonFly",
+   "dragora"        => "Dragora",
+   "drbl"           => "DRBL",
+   "duzeru"         => "DuZeru",
+   "easynas"        => "EasyNAS",
    "edubuntu"       => "Edubuntu",
    "elastix"        => "Elastix",
    "elementary"     => "elementary",
    "elive"          => "Elive",
-   "emmabuntus"     => "Emmabunt\xFCs",
+   "emmabuntus"     => "Emmabunt\xC3\x83\xC2\xBCs",
    "endian"         => "Endian",
+   "endlessos"      => "Endless",
    "exe"            => "Exe",
    "exherbo"        => "Exherbo",
    "extix"          => "ExTiX",
+   "fatdog"         => "Fatdog64",
    "fedora"         => "Fedora",
+   "ferenos"        => "feren",
    "fermi"          => "Fermi",
-   "finnix"         => "Finnix",
    "freebsd"        => "FreeBSD",
    "freenas"        => "FreeNAS",
+   "freepbx"        => "FreePBX",
+   "freespire"      => "Freespire",
    "frugalware"     => "Frugalware",
    "fuguita"        => "FuguIta",
    "funtoo"         => "Funtoo",
-   "geexbox"        => "GeeXboX",
+   "gecko"          => "Gecko",
    "gentoo"         => "Gentoo",
    "ghostbsd"       => "GhostBSD",
    "gnewsense"      => "gNewSense",
+   "gnustep"        => "GNUstep",
    "gobo"           => "GoboLinux",
    "gparted"        => "GParted",
    "greenie"        => "Greenie",
    "grml"           => "Grml",
-   "guadalinex"     => "Guadalinex",
+   "guixsd"         => "GuixSD",
    "haiku"          => "Haiku",
-   "handy"          => "HandyLinux",
-   "hanthana"       => "Hanthana",
-   "ipcop"          => "IPCop",
+   "hardenedbsd"    => "HardenedBSD",
+   "heads"          => "heads",
    "ipfire"         => "IPFire",
    "kali"           => "Kali",
    "kanotix"        => "KANOTIX",
    "kaos"           => "KaOS",
    "karoshi"        => "Karoshi",
-   "kdemar"         => "kademar",
+   "kdeneon"        => "KDE neon",
+   "keysoft"        => "Keysoft",
    "knoppix"        => "KNOPPIX",
+   "kodachi"        => "Kodachi",
    "kolibri"        => "KolibriOS",
    "korora"         => "Korora",
    "kubuntu"        => "Kubuntu",
-   "kwheezy"        => "Kwheezy",
    "kwort"          => "Kwort",
    "kxstudio"       => "KXStudio",
+   "lakka"          => "Lakka",
    "leeenux"        => "Leeenux",
    "legacy"         => "Legacy",
    "lfs"            => "LFS",
-   "linex"          => "LinEx",
+   "libreelec"      => "LibreELEC",
    "linhes"         => "LinHES",
-   "linpus"         => "Linpus",
+   "linspire"       => "Linspire",
    "linuxbbq"       => "LinuxBBQ",
    "linuxconsole"   => "LinuxConsole",
    "linuxfx"        => "Linuxfx",
-   "liquidlemur"    => "Liquid Lemur",
    "lite"           => "Lite",
+   "liveraizo"      => "Live Raizo",
    "lliurex"        => "LliureX",
-   "lps"            => "LPS",
    "lubuntu"        => "Lubuntu",
    "lunar"          => "Lunar",
    "luninux"        => "LuninuX",
    "lxle"           => "LXLE",
-   "madbox"         => "Madbox",
    "mageia"         => "Mageia",
    "makulu"         => "MakuluLinux",
    "mangaka"        => "Mangaka",
    "manjaro"        => "Manjaro",
-   "matriux"        => "Matriux",
+   "maui"           => "Maui",
    "max"            => "MAX",
+   "metamorphose"   => "Metamorphose",
    "midnightbsd"    => "MidnightBSD",
    "minino"         => "MiniNo",
    "minix"          => "MINIX",
    "mint"           => "Mint",
-   "miracle"        => "Miracle",
    "miros"          => "MirOS",
-   "momonga"        => "Momonga",
-   "musix"          => "Musix",
-   "mythbuntu"      => "Mythbuntu",
-   "nanolinux"      => "Nanolinux",
+   "mll"            => "Minimal",
+   "morpheusarch"   => "MorpheusArch",
+   "mx"             => "MX Linux",
    "nas4free"       => "NAS4Free",
    "neptune"        => "Neptune",
    "netbsd"         => "NetBSD",
    "nethserver"     => "NethServer",
    "netrunner"      => "Netrunner",
-   "netsecl"        => "NetSecL",
    "nexentastor"    => "NexentaStor",
+   "nitrux"         => "Nitrux",
    "nixos"          => "NixOS",
-   "nova"           => "Nova",
    "nst"            => "NST",
    "nutyx"          => "NuTyX",
-   "ojuba"          => "Ojuba",
+   "ob2d"           => "OB2D",
    "olpc"           => "OLPC",
    "omoikane"       => "Omoikane",
    "openbsd"        => "OpenBSD",
    "openelec"       => "OpenELEC",
    "openindiana"    => "OpenIndiana",
-   "openlx"         => "OpenLX",
-   "openmamba"      => "openmamba",
    "openmandriva"   => "OpenMandriva",
    "openmediavault" => "OpenMediaVault",
    "opensuse"       => "openSUSE",
    "openwall"       => "Openwall",
    "opnsense"       => "OPNsense",
    "oracle"         => "Oracle",
+   "osgeo"          => "OSGeo",
    "osmc"           => "OSMC",
-   "overclockix"    => "Overclockix",
-   "ozunity"        => "Oz Unity",
+   "ovios"          => "OviOS",
    "paldo"          => "paldo",
    "parabola"       => "Parabola",
    "pardus"         => "Pardus",
-   "parrotsecurity" => "Parrot Security OS",
-   "parsix"         => "Parsix",
+   "pardustopluluk" => "Pardus Topluluk",
+   "parrotsecurity" => "Parrot",
    "partedmagic"    => "Parted Magic",
-   "pcbsd"          => "PC-BSD",
    "pclinuxos"      => "PCLinuxOS",
    "peachosi"       => "Peach OSI",
+   "pearl"          => "Pearl",
    "pelicanhpc"     => "PelicanHPC",
    "pentoo"         => "Pentoo",
    "peppermint"     => "Peppermint",
    "pfsense"        => "pfSense",
-   "pidora"         => "Pidora",
+   "photonos"       => "Photon",
    "pinguy"         => "Pinguy",
    "pisi"           => "Pisi",
    "plamo"          => "Plamo",
    "pld"            => "PLD",
    "plop"           => "Plop",
    "point"          => "Point",
-   "poliarch"       => "PoliArch",
+   "popos"          => "Pop!_OS",
    "porteus"        => "Porteus",
    "porteuskiosk"   => "Porteus Kiosk",
+   "primtux"        => "PrimTux",
    "proxmox"        => "Proxmox",
    "puppy"          => "Puppy",
+   "pureos"         => "PureOS",
    "q4os"           => "Q4OS",
    "qubes"          => "Qubes",
    "quirky"         => "Quirky",
+   "rancheros"      => "RancherOS",
    "raspbian"       => "Raspbian",
+   "raspbsd"        => "RaspBSD",
+   "rasplex"        => "RasPlex",
+   "rds"            => "RDS",
    "reactos"        => "ReactOS",
+   "rebeccablackos" => "RebeccaBlackOS",
    "rebellin"       => "Rebellin",
+   "redcore"        => "Redcore",
    "redhat"         => "Red Hat",
-   "remnux"         => "REMnux",
+   "refracta"       => "Refracta",
    "rescatux"       => "Rescatux",
+   "revengeos"      => "Revenge",
    "risc"           => "RISC",
    "robolinux"      => "Robolinux",
    "rockscluster"   => "Rocks Cluster",
    "rockstor"       => "Rockstor",
    "rosa"           => "ROSA",
+   "rss"            => "RSS",
    "runtu"          => "Runtu",
    "sabayon"        => "Sabayon",
    "salentos"       => "SalentOS",
@@ -278,73 +301,80 @@ our $distros = do {
    "scientific"     => "Scientific",
    "securepoint"    => "Securepoint",
    "selks"          => "SELKS",
-   "semplice"       => "Semplice",
+   "sharklinux"     => "Shark",
    "siduction"      => "siduction",
-   "simplicity"     => "Simplicity",
-   "skolelinux"     => "Skolelinux",
+   "skolelinux"     => "Debian Edu",
    "slackel"        => "Slackel",
    "slackware"      => "Slackware",
+   "slax"           => "Slax",
    "sle"            => "SUSE",
    "slitaz"         => "SliTaz",
    "smartos"        => "SmartOS",
    "smeserver"      => "SME Server",
    "smoothwall"     => "Smoothwall",
    "sms"            => "SMS",
-   "solaris"        => "Solaris",
    "solus"          => "Solus",
    "solydxk"        => "SolydXK",
-   "sonar"          => "Sonar",
    "sophos"         => "Sophos",
    "sourcemage"     => "Source Mage",
    "sparky"         => "SparkyLinux",
    "springdale"     => "Springdale",
+   "star"           => "Star",
    "steamos"        => "SteamOS",
-   "stella"         => "Stella",
+   "subgraph"       => "Subgraph",
    "sulix"          => "SuliX",
-   "superx"         => "SuperX",
-   "symphony"       => "SymphonyOS",
+   "supergrub"      => "Super Grub2",
+   "swagarch"       => "SwagArch",
+   "swecha"         => "Swecha",
+   "swift"          => "Swift",
    "systemrescue"   => "SystemRescue",
    "t2"             => "T2",
    "tails"          => "Tails",
+   "talkingarch"    => "TalkingArch",
    "tanglu"         => "Tanglu",
+   "tens"           => "TENS",
    "thinstation"    => "Thinstation",
    "tinycore"       => "Tiny Core",
+   "tooppy"         => "ToOpPy",
+   "torios"         => "ToriOS",
    "toutou"         => "Toutou",
    "trisquel"       => "Trisquel",
-   "turbolinux"     => "Turbolinux",
+   "trueos"         => "TrueOS",
    "turnkey"        => "TurnKey",
-   "uberstudent"    => "UberStudent",
+   "tuxtrans"       => "tuxtrans",
+   "ubos"           => "UBOS",
    "ubuntu"         => "Ubuntu",
+   "ubuntubudgie"   => "Ubuntu Budgie",
    "ubuntudp"       => "Ubuntu DP",
-   "ubuntugnome"    => "Ubuntu GNOME",
    "ubuntukylin"    => "Ubuntu Kylin",
    "ubuntumate"     => "Ubuntu MATE",
-   "ubuntupr"       => "UPR",
    "ubuntustudio"   => "Ubuntu Studio",
    "uhu"            => "UHU-Linux",
    "ulteo"          => "Ulteo",
    "ultimate"       => "Ultimate",
-   "unity"          => "Unity",
    "univention"     => "Univention",
    "untangle"       => "Untangle",
+   "urix"           => "URIX",
+   "uruk"           => "Uruk",
+   "ututo"          => "UTUTO",
    "vector"         => "Vector",
    "vine"           => "Vine",
+   "vinux"          => "Vinux",
    "void"           => "Void",
    "volumio"        => "Volumio",
-   "vortexbox"      => "VortexBox",
    "voyager"        => "Voyager",
    "vyos"           => "VyOS",
    "wattos"         => "wattOS",
    "webconverger"   => "Webconverger",
+   "whonix"         => "Whonix",
    "wifislax"       => "Wifislax",
    "wmlive"         => "WM Live",
-   "xange"          => "Open Xange",
    "xstreamos"      => "XStreamOS",
    "xubuntu"        => "Xubuntu",
    "zentyal"        => "Zentyal",
    "zenwalk"        => "Zenwalk",
    "zeroshell"      => "Zeroshell",
-   "zevenos"        => "ZevenOS",
+   "zevenet"        => "Zevenet",
    "zorin"          => "Zorin",
  }
 
@@ -505,12 +535,16 @@ WWW::DistroWatch::ReleaseInfo - Get information about a distro's releases
 
 =head1 VERSION
 
-This document describes version 0.05 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2015-10-06.
+This document describes version 0.06 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2018-01-22.
 
 =head1 FUNCTIONS
 
 
-=head2 get_distro_releases_info(%args) -> [status, msg, result, meta]
+=head2 get_distro_releases_info
+
+Usage:
+
+ get_distro_releases_info(%args) -> [status, msg, result, meta]
 
 Get information about a distro's releases.
 
@@ -560,7 +594,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 list_distros(%args) -> [status, msg, result, meta]
+=head2 list_distros
+
+Usage:
+
+ list_distros(%args) -> [status, msg, result, meta]
 
 List all known distros.
 
@@ -588,7 +626,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 list_distros_cached() -> [status, msg, result, meta]
+=head2 list_distros_cached
+
+Usage:
+
+ list_distros_cached() -> [status, msg, result, meta]
 
 List all known distros (cached data).
 
@@ -629,7 +671,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
